@@ -30,6 +30,8 @@ ESCAPED_FRAGMENT_REPLACEMENT = StringReplacement(
 TITLE_REPLACEMENTS = ReplaceSequence().create(u"&raquo;").append(u"»")
 PIPE_SPLITTER = StringSplitter("\\|")
 DASH_SPLITTER = StringSplitter(" - ")
+UNDERSCORE_SPLITTER = StringSplitter("_")
+SLASH_SPLITTER = StringSplitter("/")
 ARROWS_SPLITTER = StringSplitter("»")
 COLON_SPLITTER = StringSplitter(":")
 SPACE_SPLITTER = StringSplitter(' ')
@@ -182,6 +184,15 @@ class ContentExtractor(object):
             title_text = self.split_title(title_text, DASH_SPLITTER)
             used_delimeter = True
 
+        # split title with _
+        if not used_delimeter and '_' in title_text:
+            title_text = self.split_title(title_text, UNDERSCORE_SPLITTER)
+
+        # split title with /
+        if not used_delimeter and '/' in title_text:
+            title_text = self.split_title(title_text, SLASH_SPLITTER)
+            used_delimeter = True
+
         # split title with »
         if not used_delimeter and u'»' in title_text:
             title_text = self.split_title(title_text, ARROWS_SPLITTER)
