@@ -114,7 +114,7 @@ class StopWordsChinese(StopWords):
     def candidate_words(self, stripped_input):
         # jieba builds a tree that takes a while. avoid building
         # this tree if we don't use the chinese language
-        from .packages import jieba
+        import jieba
         return jieba.cut(stripped_input, cut_all=True)
 
 
